@@ -21,7 +21,7 @@ our ( $VERSION, $COMPATIBLE, $FILENAME );
 
 
 # $VERSION is also in Parse/Eyapp.pm
-$VERSION = "1.160";
+$VERSION = "1.162";
 $COMPATIBLE = '0.07';
 $FILENAME   =__FILE__;
 
@@ -29,7 +29,6 @@ use Carp;
 use Scalar::Util qw{blessed reftype looks_like_number};
 
 use Getopt::Long;
-use Pod::Usage;
 
 #Known parameters, all starting with YY (leading YY will be discarded)
 my (%params)=(YYLEX => 'CODE', 'YYERROR' => 'CODE', YYVERSION => '',
@@ -1340,7 +1339,7 @@ sub main {
     "margin=i"       => \$Parse::Eyapp::Node::INDENT,      
   );
 
-  pod2usage() if $help;
+  $package->_help() if $help;
 
   $debug = 0x1F if $debug;
   $file = shift if !$file && @ARGV; # file is taken from the @ARGS unless already defined
@@ -1410,6 +1409,32 @@ sub main {
   }
 }
 
+sub _help {
+  my $package = shift;
+
+  print << 'AYUDA';
+Available options:
+    --debug                    sets yydebug on
+    --nodebug                  sets yydebug off
+    --file filepath            read input from filepath
+    --commandinput string      read input from string
+    --tree                     prints $tree->str
+    --notree                   does not print $tree->str
+    --info                     When printing $tree->str shows the value of TERMINALs
+    --help                     shows this help
+    --slurp                    read until EOF reached
+    --noslurp                  read until CR is reached
+    --argfile                  main() will take the input string from its @_
+    --noargfile                main() will not take the input string from its @_
+    --yaml                     dumps YAML for $tree: YAML module must be installed
+    --margin=i                 controls the indentation of $tree->str (i.e. $Parse::Eyapp::Node::INDENT)      
+AYUDA
+
+  $package->help() if ($package & $package->can("help"));
+
+  exit(0);
+}
+
 # Generic error handler
 # Convention adopted: if the attribute of a token is an object
 # assume it has 'line' and 'str' methods. Otherwise, if it
